aboutsummaryrefslogtreecommitdiffstats
path: root/include/queue_fn.php
diff options
context:
space:
mode:
Diffstat (limited to 'include/queue_fn.php')
-rw-r--r--include/queue_fn.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/queue_fn.php b/include/queue_fn.php
index 0708aab56..676620e2f 100644
--- a/include/queue_fn.php
+++ b/include/queue_fn.php
@@ -101,7 +101,7 @@ function queue_deliver($outq, $immediate = false) {
}
}
- $arr = array('outq' => $outq, 'handled' => false, 'immediate' => $immediate);
+ $arr = array('outq' => $outq, 'base' => $base, 'handled' => false, 'immediate' => $immediate);
call_hooks('queue_deliver',$arr);
if($arr['handled'])
return;
@@ -126,7 +126,7 @@ function queue_deliver($outq, $immediate = false) {
remove_queue_item($outq['outq_hash']);
// server is responding - see if anything else is going to this destination and is piled up
// and try to send some more. We're relying on the fact that delivery_loop() results in an
// immediate delivery otherwise we could get into a queue loop.
if(! $immediate) {
@@ -141,7 +141,7 @@ function queue_deliver($outq, $immediate = false) {
}
}
if($piled_up) {
- delivery_loop($piled_up);
+ do_delivery($piled_up);
}
}
}
@@ -126,7 +126,7 @@ function queue_deliver($outq, $immediate = false) {
remove_queue_item($outq['outq_hash']);
// server is responding - see if anything else is going to this destination and is piled up
- // and try to send some more. We're relying on the fact that delivery_loop() results in an
+ // and try to send some more. We're relying on the fact that do_delivery() results in an
// immediate delivery otherwise we could get into a queue loop.
if(! $immediate) {